
# Enum: FlatDtype




URI: [nwb_schema_language:FlatDtype](https://w3id.org/p2p_ld/nwb-schema-language/FlatDtype)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| float | single precision floating point (32 bit) |  |  |
| float32 | single precision floating point (32 bit) |  |  |
| double | double precision floating point (64 bit) |  |  |
| float64 | double precision floating point (64 bit) |  |  |
| long | signed 64 bit integer |  |  |
| int64 | signed 64 bit integer |  |  |
| int | signed 32 bit integer |  |  |
| int32 | signed 32 bit integer |  |  |
| int16 | signed 16 bit integer |  |  |
| short | signed 16 bit integer |  |  |
| int8 | signed 8 bit integer |  |  |
| uint | unsigned 32 bit integer |  |  |
| uint32 | unsigned 32 bit integer |  |  |
| uint16 | unsigned 16 bit integer |  |  |
| uint8 | unsigned 8 bit integer |  |  |
| uint64 | unsigned 64 bit integer |  |  |
| numeric | any numeric type (i.e., any int, uint, float) |  |  |
| text | 8-bit Unicode |  |  |
| utf | 8-bit Unicode |  |  |
| utf8 | 8-bit Unicode |  |  |
| utf-8 | 8-bit Unicode |  |  |
| ascii | ASCII text |  |  |
| bool | 8 bit integer with valid values 0 or 1 |  |  |
| isodatetime | ISO 8601 datetime string |  | {'examples': [Example(value='2018-09-28 14:43:54.123000+02:00', description=None, object=None)]} |

